@@ -27,7 +27,7 @@
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
  * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	@(#)$Id: 13d536db0c82ce396fd05e7ce4426d0d2397999f $
+ *	@(#)$Id: defs.h,v 1.1 2018/06/14 00:00:00 jneitzel $
  */
 
 #ifndef	DEFS_H
@@ -48,10 +48,12 @@
 #include <errno.h>
 #include <fcntl.h>
 #include <grp.h>
+#include <inttypes.h>
 #include <limits.h>
 #include <pwd.h>
 #include <stdbool.h>
 #include <stddef.h>
+#include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -183,4 +185,16 @@ typedef	unsigned char	UChar;
 #define	UCHAR(c)	((UChar)(c))
 #define	UCPTR(p)	((UChar *)(p))
 
+#ifndef	lint
+#ifndef	ETSH_ATTR
+# if __GNUC__ > 3 || __GNUC__ == 3 && __GNUC_MINOR__ >= 4
+#  define	ETSH_ATTR	__attribute__((__used__))
+# elif defined(__GNUC__)
+#  define	ETSH_ATTR	__attribute__((__unused__))
+# else
+#  define	ETSH_ATTR	/* nothing */
+# endif
+#endif	/* !ETSH_ATTR */
+#endif	/* !lint */
+
 #endif	/* !DEFS_H */
