@@ -26,7 +26,7 @@
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
  * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	@(#)$Id: 5a531c2b182731a0b30d008f6fb537ac3a6f6d52 $
+ *	@(#)$Id: etsh.c,v 1.1 2018/06/14 00:00:00 jneitzel $
  */
 /*
  *	Derived from:
@@ -37,8 +37,6 @@
  *			sh6.c	(1.3 (jneitzel) 2006/09/15)
  *			glob6.c	(1.3 (jneitzel) 2006/09/23)
  */
-/*
- */
 /*-
  * Copyright (C) Caldera International Inc.  2001-2002.  All rights reserved.
  *
@@ -386,7 +384,6 @@ main(int argc, char **argv)
 	int rcflag = 0;
 	bool dosigs = false;
 
-	/* Start the shell rolling if possible. */
 	sh_init(argv[0]);
 	if (argv[0] == NULL || *argv[0] == EOS)
 		sh_err(SH_ERR, FMT2S, getmyname(), ERR_ALINVAL);
@@ -396,11 +393,13 @@ main(int argc, char **argv)
 	/* Handle the -V and -VV options (no getopt(3)). */
 	if (argc == 2 && *argv[1] == HYPHEN && argv[1][1] == 'V') {
 		status = SH_TRUE;
-		if (argv[1][2] == EOS)
+		if (argv[1][2] == EOS) {
+			fd_print(FD2, ETSH_VNUM_URL, ETSH_VNUM, ETSH_URL);
 			fd_print(FD1, FMT1S, ETSH_VERSION);
-		else if (argv[1][2] == 'V' && argv[1][3] == EOS)
-			fd_print(FD1, "%s (%s)\n", ETSH_VERSION,ETSH_UNAME_SRM);
-		else
+		} else if (argv[1][2] == 'V' && argv[1][3] == EOS) {
+			fd_print(FD2, ETSH_VNUM_URL, ETSH_VNUM, ETSH_URL);
+			fd_print(FD1,"%s ( %s )\n",ETSH_VERSION,ETSH_UNAME_SRM);
+		} else
 			usage();
 		goto done;
 	}
@@ -627,6 +626,7 @@ usage(void)
 
 	misc_free();
 	n = getmyname();
+	fd_print(FD2, ETSH_VNUM_URL, ETSH_VNUM, ETSH_URL);
 	sh_err(SH_ERR, ETSH_USAGE, n, n);
 }
 
