@@ -26,13 +26,22 @@
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
  * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	@(#)$Id: b8db64aecf2a025ff0d282b9331fdcbea84b8434 $
+ *	@(#)$Id: fd2.c,v 1.1 2018/06/14 00:00:00 jneitzel $
  */
 
 #include "defs.h"
 #include "sh_err.h"
 #include "pexec.h"
 
+#ifndef	lint
+/*@unused@*/
+static const char *const vcid[] ETSH_ATTR = {
+	"\100(#)\044Id: etsh " ETSH_VNUM " ( " ETSH_URL " ) \044",
+	"\100(#)\044Id: " ETSH_VERSION " ( " ETSH_UNAME_SRM " ) \044",
+	"\100(#)\044Id: Copyright (c) 2005-2018 Jeffrey Allen Neitzel. \044"
+};
+#endif	/* !lint */
+
 const char	*name;
 bool		no_lnum	= true;	/* no line number flag */
 
@@ -78,8 +87,7 @@ main(int argc, char **argv)
 			sh_err(FC_ERR, "%s: %u: %s\n",
 				getmyname(), (unsigned)fd, strerror(errno));
 
-	ofd = FD1, efd = FD2;
-	eopt = false, file = NULL;
+	ofd = FD1, efd = FD2, eopt = false, file = NULL;
 	while ((opt = getopt(argc, argv, ":ef:")) != -1)
 		switch (opt) {
 		case 'e':
