@@ -26,7 +26,7 @@
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
  * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	@(#)$Id: 11931d88d5b7dec3999505357ff43443e4358266 $
+ *	@(#)$Id: goto.c,v 1.1 2018/06/14 00:00:00 jneitzel $
  */
 /*
  *	Derived from: Sixth Edition UNIX /usr/source/s1/goto.c
@@ -116,7 +116,7 @@ main(int argc, char **argv)
 	if (lseek(FD0, (off_t)0, SEEK_SET) == -1)
 		sh_err(FC_ERR, FMT2S, getmyname(), ERR_SEEK);
 
-	while (getlabel(label, *argv[1] & 0377, siz))
+	while (getlabel(label, UCHAR(*argv[1] & 0377), siz))
 		if (strcmp(label, argv[1]) == 0) {
 #if !(defined(CONFIG_LINUX) || defined(CONFIG_SUNOS))
 			(void)lseek(FD0, offset, SEEK_SET);
@@ -199,10 +199,16 @@ xgetc(void)
 
 	offset++;
 	nc = getchar();
-	return (nc != EOF) ? nc & 0377 : EOF;
+	if (nc != EOF) {
+		nc = UCHAR(nc & 0377);
+		return nc;
+	}
+	return EOF;
 #else
 	unsigned char nc;
 
-	return (read(FD0, &nc, (size_t)1) == 1) ? nc : EOF;
+	if (read(FD0, &nc, (size_t)1) == 1)
+		return nc;
+	return EOF;
 #endif
 }
