@@ -26,7 +26,7 @@
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
  * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	@(#)$Id: 64441c3fcab9cd626c2aa7a3af5d4b8893014313 $
+ *	@(#)$Id: tsh.c,v 1.1 2018/06/14 00:00:00 jneitzel $
  */
 /*
  *	Derived from: Sixth Edition UNIX /usr/source/s2/sh.c
@@ -166,6 +166,7 @@ static	bool		fd_isdir(int);
 static	void		xfree(/*@null@*/ /*@only@*/ void *);
 /*@maynotreturn@*/ /*@out@*/
 static	void		*xmalloc(size_t);
+static	void		setenv_tes(void);
 
 /*
  * NAME
@@ -182,7 +183,6 @@ main(int argc, char **argv)
 {
 	bool dosigs = false;
 
-	/* Start the shell rolling if possible. */
 	sh_init(argv[0]);
 	if (argv[0] == NULL || *argv[0] == EOS)
 		sh_err(SH_ERR, FMT1S, ERR_ALINVAL);
@@ -234,6 +234,7 @@ loop:
 	goto loop;
 
 done:
+	setenv_tes();
 	return status;
 }
 
@@ -453,18 +454,24 @@ readc(void)
 	char c;
 
 	if (argv2p != NULL) {
-		if (argv2p == (char *)-1)
+		if (argv2p == (char *)-1) {
+			setenv_tes();
 			exit(status);
+		}
 		if ((c = (*argv2p++ & ASCII)) == EOS) {
 			argv2p = (char *)-1;
 			c = EOL;
 		}
 		return c;
 	}
-	if (one_line_flag == 1)
+	if (one_line_flag == 1) {
+		setenv_tes();
 		exit(status);
-	if (read(FD0, &c, (size_t)1) != 1)
+	}
+	if (read(FD0, &c, (size_t)1) != 1) {
+		setenv_tes();
 		exit(status);
+	}
 	if ((c &= ASCII) == EOL && one_line_flag == 2)
 		one_line_flag = 1;
 
@@ -863,6 +870,7 @@ execute(struct tnode *t, int *pin, int *pout)
 		cmd = t->nav[0];
 		if (EQUAL(cmd, ":")) {
 			status = SH_TRUE;
+			setenv_tes();
 			return;
 		}
 		if (EQUAL(cmd, "chdir")) {
@@ -873,9 +881,11 @@ execute(struct tnode *t, int *pin, int *pout)
 				sh_err(SH_ERR, FMT2S, cmd, ERR_BADDIR);
 			else
 				status = SH_TRUE;
+			setenv_tes();
 			return;
 		}
 		if (EQUAL(cmd, "exit")) {
+			setenv_tes();
 			if (prompt == NULL) {
 				(void)lseek(FD0, (off_t)0, SEEK_END);
 				EXIT(status);
@@ -900,6 +910,7 @@ execute(struct tnode *t, int *pin, int *pout)
 				dolv = &dolv[1];
 				dolc--;
 				status = SH_TRUE;
+				setenv_tes();
 				return;
 			}
 			sh_err(SH_ERR, FMT2S, cmd, ERR_NOARGS);
@@ -1092,6 +1103,7 @@ pwait(pid_t cp)
 		if (tp == cp)
 			break;
 	}
+	setenv_tes();
 }
 
 /*
@@ -1145,6 +1157,7 @@ sh_errexit(int es)
 #endif
 
 	status = es;
+	setenv_tes();
 	if (prompt == NULL) {
 		(void)lseek(FD0, (off_t)0, SEEK_END);
 		EXIT(status);
@@ -1288,3 +1301,26 @@ xmalloc(size_t s)
 	}
 	return mp;
 }
+
+/*
+ * Set TES (short for TSH_EXIT_STATUS) in the environment w/o
+ * changing the current value of the global variable status.
+ * Set TES to the empty string on snprintf(3) error or what
+ * would have indicated an overflow condition.  Print a
+ * diagnostic on setenv(3) error, but do not error exit.
+ */
+static void
+setenv_tes(void)
+{
+	char buf[SBUFMM(1)];
+	int r, ss;
+
+	ss = status;
+	*buf = EOS;
+	r = snprintf(buf, sizeof(buf), "%u", (unsigned int)status);
+	if (r < 0 || r >= (int)sizeof(buf))
+		*buf = EOS;
+	if (setenv("TES", buf, 1) == -1)
+		fd_print(FD2, FMT2S, __func__, ERR_NOMEM);
+	status = ss;
+}
