@@ -26,10 +26,11 @@
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
  * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	@(#)$Id: a3eb4fa5ff6086b5c5837fb1d48f0f2fdadf2c3d $
+ *	@(#)$Id: util.c,v 1.1 2018/06/14 00:00:00 jneitzel $
  */
 /*
- *	Derived from: osh-20080629
+ *	Derived from:
+ *		- osh-20080629
  *			fd2.c	(r404 2008-05-09 16:52:15Z jneitzel)
  *			goto.c	(r465 2008-06-25 22:11:58Z jneitzel)
  *			if.c	(r465 2008-06-25 22:11:58Z jneitzel)
@@ -99,7 +100,8 @@ uexec(enum sbikey key, int ac, char **av)
 	int r;
 	static int cnt, cnt1, s;
 
-	if (cnt == 0) setmyerrexit(&ut_errexit);
+	if (cnt == 0)
+		setmyerrexit(&ut_errexit);
 
 	switch (key) {
 	case SBI_ECHO:	util = &sbi_echo;	break;
@@ -121,7 +123,8 @@ uexec(enum sbikey key, int ac, char **av)
 
 #ifdef	DEBUG
 #ifdef	DEBUG_PROC
-	if (cnt == 0) fd_print(FD2, "%s: return %d;\n", __func__, s);
+	if (cnt == 0)
+		fd_print(FD2, "%s: return %d;\n", __func__, s);
 #endif
 #endif
 
@@ -266,7 +269,7 @@ sbi_goto(int argc, char **argv)
 	if (lseek(FD0, (off_t)0, SEEK_SET) == -1)
 		sh_err(FC_ERR, FMT2S, getmyname(), ERR_SEEK);
 
-	while (getlabel(label, *argv[1] & 0377, siz))
+	while (getlabel(label, UCHAR(*argv[1] & 0377), siz))
 		if (strcmp(label, argv[1]) == 0) {
 			(void)lseek(FD0, offset, SEEK_SET);
 			return SH_TRUE;
@@ -346,7 +349,11 @@ xgetc(void)
 
 	offset++;
 	nc = getchar();
-	return (nc != EOF) ? nc & 0377 : EOF;
+	if (nc != EOF) {
+		nc = UCHAR(nc & 0377);
+		return nc;
+	}
+	return EOF;
 }
 
 static	int	iac;
