@@ -26,25 +26,16 @@
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
  * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	@(#)$Id: f709866583d0fb12c9616339240b6ccc4bc39bbf $
+ *	@(#)$Id: v.c,v 1.1 2018/06/14 00:00:00 jneitzel $
  */
 
-#include "config.h"
+#include "defs.h"
 
 #ifndef	lint
-#ifndef	ETSH_ATTR
-# if __GNUC__ > 3 || __GNUC__ == 3 && __GNUC_MINOR__ >= 4
-#  define	ETSH_ATTR	__attribute__((__used__))
-# elif defined(__GNUC__)
-#  define	ETSH_ATTR	__attribute__((__unused__))
-# else
-#  define	ETSH_ATTR	/* nothing */
-# endif
-#endif	/* !ETSH_ATTR */
-
 /*@unused@*/
 static const char *const vcid[] ETSH_ATTR = {
-	"\100(#)\044Id: " ETSH_VERSION " (" ETSH_UNAME_SRM ") \044",
+	"\100(#)\044Id: etsh " ETSH_VNUM " ( " ETSH_URL " ) \044",
+	"\100(#)\044Id: " ETSH_VERSION " ( " ETSH_UNAME_SRM " ) \044",
 	"\100(#)\044Id: Copyright (c) 2003-2018 Jeffrey Allen Neitzel. \044",
 	"\100(#)\044Id: Copyright (c) 2001-2002 Caldera International Inc. \044",
 	"\100(#)\044Id: Copyright (c) 1980, 1985, 1989, 1990, 1991, 1993 The Regents of the University of California. \044"
